==> go.php?file=RaidSlackCheck6.104.zip: RaidSlackCheck/Localization/localization-enEN.lua <==
﻿


function rsclocale()

rscchatlist1				= "raid"
rscchatlist2				= "raid warning"
rscchatlist3				= "officer"
rscchatlist4				= "party"
rscchatlist5				= "guild"
rscchatlist6				= "say"
rscchatlist7				= "yell"
rscchatlist8				= "self only"
rsclocrlslak				= "report RL slack"
rsclocpot2				= "0 selected potions"
rsclocrep1				= "Report in chat:"
rsclocnotinc				= "out of combat (prepots)"
rscloclastf				= "last fight"
rsclocallpot				= "all potions"
rsclocpot3				= "0 potions"
rsclocfight1				= "last fight"
rsclocfight2				= "previous fight"
rsclocfight3				= "fight"
rsclocpot4				= "Everybody used potions"
rsclocpot5				= "Info about"
rsclocpot6				= "0 potions: "
rsclocpot7				= "no slack detected"
rsclocpot8				= "Other potions used: "
rsclocpot9				= "no other potions were used."
rsclocpot10				= "Who used potion"
rsclocpot11				= "Who didn't use"
rsclocpot12				= "Potions before previous combat:"
rsclocpot13				= "Used potions before previous combat"
rsclocpot14				= "Before previous combat noone used potions."
rsclocpot15				= "Used potions before previous combat only"
rsclocpot16				= "0 potions before previous combat"
rsclocpot17				= "Nobody used potions"
rsclocpot18				= "Used potions"
rscloccolor				= "color names"
rscbuttonreset				= "Reset"
rscsec					= "sec."
rscmin					= "minutes"
rscmanualsend				= "manual send:"
rscbuffspart1				= "This module check buffs that were choosen in"
rscbuffspart2				= "after rebirth and reports which are missing, then - recheck them in"
rscbuffspart3				= "You can set responsibles for buffs, then if they are alive in a raid - whisper on first check will be send only to them, otherwise - to everyone who can buff."
rscparton3				= "ENABLE"
rscpartanons31				= "announce in chat on 1 check"
rscpartanons32				= "announce in chat on 2 check"
rscpartanons33				= "send whispers on 1 check"
rscpartanons34				= "send whispers on 2 check"
rscpartanons35				= "announce without promote"
rscpartwhobuff1				= "Responsibles for buffs:"
psfpotchecklocal			= "Potions check"
psfpotchecklocalt2			= "Flask check"
psfpotchecklocalt3			= "Rebirth - Rebuff"
psfpotchecklocalt322			= "Buffs check after rebirth in combat"
rscbuffnameslitnew1			= "5% stats"
rscbuffnameslitnew2			= "Stamina"
rscbuffnameslitnew3			= "Shadow Protection"
rscbuffnameslitnew4			= "Intellect"
rscbuffnameslitnew5			= "BoM"
rscreleasedtxt1				= "was rebirth"
rscreleasedtxt1f			= "was rebirth"
rscreleasedtxt2				= "ago"
rscreleasedtxt3				= "Missing"
rscreleasedtxt4				= "STILL MISSING"
rscreleasedtxt5				= "second check"
rscreleasedtxt6				= "but is still missing"
rscreleasedtxt6f			= "but is still missing"
rscreleasedtxt7				= "but missing"
rscreleasedtxt7f			= "but missing"
rscflasktext1				= "Except normal flask & food check this module has unique options to auto-check and report slackers on boss fight start, ready check or Pull-timer (using PhoenixStyle addon) begin (max 1 check for 50 sec exept check on combat start)."
rscsend					= "Update & Send"
rscreloadbutton				= "Update"
rscflasktextc11				= "announce on boss pull"
rscflasktextc12				= "announce on 'Pull' timer started"
rscflasktextc13				= "announce on 'Ready check' started"
rscflasktextc14				= "send whispers on auto-check"
rscflasktextc15				= "check food"
rscflasktext2				= "chat for auto-check:"
rscflasktext3				= "Check first"
rscflasktext4				= "Only one Elixir"
rscflasktext5				= "No Flask"
rscflasktext6				= "no one has it"
rscflasktext7				= "No Food Buff"
rscflasktext8				= "Food Buff has only"
rscflasktext9				= "Not checked"
rscflasktext10				= "Everyone has flask and food buff."
rscflasktext11				= "Everyone has flask."
rscflasktext12				= "No data. There are many died/offline"
rscflasktxtgroup5			= "groups"
rscflasktxtgroup2			= "groups"
rscflaskwhisptxt1			= "RSC > You have no Food Buff!"
rscflaskwhisptxt2			= "RSC > You have used only 1 Elixir!"
rscflaskwhisptxt3			= "RSC > You have no Flask or Elixir!"
rscflaskwhisptxt4			= "RSC > You have no Food Buff and only 1 elixir!"
rscflaskwhisptxt5			= "RSC > You have no Flask and Food Buff!"
rscpartanons36				= "if elixirs are using - check for 2, not only 1"
rscflasktext1part2			= "Buff is not considered if it duration is below |cffff0000%s|r min."
rscbuttonztext1				= "Add current zone"
rscbuttonztext2				= "Delete current zone"
rscbuttonztext3				= "Show list"
rscbuttonztext4				= "Reset list"
rscaddonnotworkinz			= "Addon is enabled in some zones:"
rsczonereport1				= "Addon is enabled in: "
rsczonereport2				= "Addon will now work in zone: "
rsczonereport3				= "Addon will not work in: "
rsczonereport5				= "List is now empty! Addon will NOT work in all instance now!"
rsczonereport6				= "list empty"
rsczonereport7				= "|cffff0000Error!|r Current zone is already in a list!"
rsczonereport8				= "|cffff0000Error!|r Current zone was not found in a list!"
rsczonereport9				= "To reset black list - click the button |cffff0000TWICE|r"
rscflaskwhisptxt11			= "RSC > Your Food Buff will soon expire."
rscflaskwhisptxt33			= "RSC > Your Flask will soon expire."
rscflaskwhisptxt40			= "RSC > You have no Food Buff and Flask will soon expire."
rscflaskwhisptxt44			= "RSC > Your Food Buff will soon expire and you have only 1 elixir!"
rscflaskwhisptxt55			= "RSC > You have no Flask and your Food Buff will soon expire!"
rscflaskwhisptxt56			= "RSC > Your Flask and Food Buff will soon expire."
rsconlybossfigtloc			= "only boss fights"
rsconlybossfig1				= "Now potion's use will be checked only in boss fights"
rsconlybossfig2				= "Now potion's use will be checked in any combat"
rscflasktext555				= "OLD Flask"
rsctablereptxt1				= "announce when someone set up feast of food"
rsctablereptxt2				= "announce when someone set up cauldron with flasks"
rsctablereptxt3				= "announce when someone set up a Repair Bot"
rsctablereptxt4				= "announce when someone is casting a Soul Well"
rsctableused1				= "has set up a Food Feast!"
rsctableused2				= "has set up a Cauldron with Flasks!"
rsctableused3				= "has set up a Repair Bot!"
rsctableused4				= "is casting a Soul Well!"
rscfoodstillthere			= "Feast of Food is still there"
rsclocpoths17				= "Nobody used Healthstone (Tonic)"
rsclocpoths172				= "Everyone has used Healthstone (Tonic)"
rsclocpoths18				= "Used healthstones (Tonic)"
rsclocpoths182				= "NOT used healthstones (Tonic)"
rscwhousehstext				= "Used healthstone (Tonic)"
rscwhousehstext2			= "NOT used healthstone (Tonic)"
rscprepots            = "Prepots"
rscadditionalstat1    = "Stam"
rscadditionalstat2    = "Int"
rscadditionalstat3    = "Spirit"
rscadditionalstat4    = "Agi"
rscadditionalstat5    = "Str"
rscadditionalstatbonus = "bonus"
rscpartanonsfoodadd        = "count %s food"
rsceating				= "E"
rsceating2				= "E"
rsccheckrunes			= "Check runes"
rscflasktext69				= "No Runes"


end

==> go.php?file=RaidSlackCheck8.005.zip: RaidSlackCheck/Localization/localization-enEN.lua <==
﻿


function rsclocale()

rscchatlist1				= "raid"
rscchatlist2				= "raid warning"
rscchatlist3				= "officer"
rscchatlist4				= "party"
rscchatlist5				= "guild"
rscchatlist6				= "say"
rscchatlist7				= "yell"
rscchatlist8				= "self only"
rsclocrlslak				= "report RL slack"
rsclocpot2				= "0 selected potions"
rsclocrep1				= "Report in chat:"
rsclocnotinc				= "out of combat (prepots)"
rscloclastf				= "last fight"
rsclocallpot				= "all potions"
rsclocpot3				= "0 potions"
rsclocfight1				= "last fight"
rsclocfight2				= "previous fight"
rsclocfight3				= "fight"
rsclocpot4				= "Everybody used potions"
rsclocpot5				= "Info about"
rsclocpot6				= "0 potions: "
rsclocpot7				= "no slack detected"
rsclocpot8				= "Other potions used: "
rsclocpot9				= "no other potions were used."
rsclocpot10				= "Who used potion"
rsclocpot11				= "Who didn't use"
rsclocpot12				= "Potions before previous combat:"
rsclocpot13				= "Used potions before previous combat"
rsclocpot14				= "Before previous combat noone used potions."
rsclocpot15				= "Used potions before previous combat only"
rsclocpot16				= "0 potions before previous combat"
rsclocpot17				= "Nobody used potions"
rsclocpot18				= "Used potions"
rscloccolor				= "color names"
rscbuttonreset				= "Reset"
rscsec					= "sec."
rscmin					= "minutes"
rscmanualsend				= "manual send:"
rscbuffspart1				= "This module check buffs that were choosen in"
rscbuffspart2				= "after rebirth and reports which are missing, then - recheck them in"
rscbuffspart3				= "You can set responsibles for buffs, then if they are alive in a raid - whisper on first check will be send only to them, otherwise - to everyone who can buff."
rscparton3				= "ENABLE"
rscpartanons31				= "announce in chat on 1 check"
rscpartanons32				= "announce in chat on 2 check"
rscpartanons33				= "send whispers on 1 check"
rscpartanons34				= "send whispers on 2 check"
rscpartanons35				= "announce without promote"
rscpartwhobuff1				= "Responsibles for buffs:"
psfpotchecklocal			= "Potions check"
psfpotchecklocalt2			= "Flask check"
psfpotchecklocalt3			= "Rebirth - Rebuff"
psfpotchecklocalt322			= "Buffs check after rebirth in combat"
rscbuffnameslitnew1			= "5% stats"
rscbuffnameslitnew2			= "Stamina"
rscbuffnameslitnew3			= "Shadow Protection"
rscbuffnameslitnew4			= "Intellect"
rscbuffnameslitnew5			= "BoM"
rscreleasedtxt1				= "was rebirth"
rscreleasedtxt1f			= "was rebirth"
rscreleasedtxt2				= "ago"
rscreleasedtxt3				= "Missing"
rscreleasedtxt4				= "STILL MISSING"
rscreleasedtxt5				= "second check"
rscreleasedtxt6				= "but is still missing"
rscreleasedtxt6f			= "but is still missing"
rscreleasedtxt7				= "but missing"
rscreleasedtxt7f			= "but missing"
rscflasktext1				= "Except normal flask & food check this module has unique options to auto-check and report slackers on boss fight start, ready check or Pull-timer (using PhoenixStyle addon) begin (max 1 check for 50 sec exept check on combat start)."
rscsend					= "Update & Send"
rscreloadbutton				= "Update"
rscflasktextc11				= "announce on boss pull"
rscflasktextc12				= "announce on 'Pull' timer started"
rscflasktextc13				= "announce on 'Ready check' started"
rscflasktextc14				= "send whispers on auto-check"
rscflasktextc15				= "check food"
rscflasktext2				= "chat for auto-check:"
rscflasktext3				= "Check first"
rscflasktext4				= "Only one Elixir"
rscflasktext5				= "No Flask"
rscflasktext6				= "no one has it"
rscflasktext7				= "No Food Buff"
rscflasktext8				= "Food Buff has only"
rscflasktext9				= "Not checked"
rscflasktext10				= "Everyone has flask and food buff."
rscflasktext11				= "Everyone has flask."
rscflasktext12				= "No data. There are many died/offline"
rscflasktxtgroup5			= "groups"
rscflasktxtgroup2			= "groups"
rscflaskwhisptxt1			= "RSC > You have no Food Buff!"
rscflaskwhisptxt2			= "RSC > You have used only 1 Elixir!"
rscflaskwhisptxt3			= "RSC > You have no Flask or Elixir!"
rscflaskwhisptxt4			= "RSC > You have no Food Buff and only 1 elixir!"
rscflaskwhisptxt5			= "RSC > You have no Flask and Food Buff!"
rscpartanons36				= "if elixirs are using - check for 2, not only 1"
rscflasktext1part2			= "Buff is not considered if it duration is below |cffff0000%s|r min."
rscbuttonztext1				= "Add current zone"
rscbuttonztext2				= "Delete current zone"
rscbuttonztext3				= "Show list"
rscbuttonztext4				= "Reset list"
rscaddonnotworkinz			= "Addon is enabled in some zones:"
rsczonereport1				= "Addon is enabled in: "
rsczonereport2				= "Addon will now work in zone: "
rsczonereport3				= "Addon will not work in: "
rsczonereport5				= "List is now empty! Addon will NOT work in all instance now!"
rsczonereport6				= "list empty"
rsczonereport7				= "|cffff0000Error!|r Current zone is already in a list!"
rsczonereport8				= "|cffff0000Error!|r Current zone was not found in a list!"
rsczonereport9				= "To reset black list - click the button |cffff0000TWICE|r"
rscflaskwhisptxt11			= "RSC > Your Food Buff will soon expire."
rscflaskwhisptxt33			= "RSC > Your Flask will soon expire."
rscflaskwhisptxt40			= "RSC > You have no Food Buff and Flask will soon expire."
rscflaskwhisptxt44			= "RSC > Your Food Buff will soon expire and you have only 1 elixir!"
rscflaskwhisptxt55			= "RSC > You have no Flask and your Food Buff will soon expire!"
rscflaskwhisptxt56			= "RSC > Your Flask and Food Buff will soon expire."
rsconlybossfigtloc			= "only boss fights"
rsconlybossfig1				= "Now potion's use will be checked only in boss fights"
rsconlybossfig2				= "Now potion's use will be checked in any combat"
rscflasktext555				= "OLD Flask"
rsctablereptxt1				= "announce when someone set up feast of food"
rsctablereptxt2				= "announce when someone set up cauldron with flasks"
rsctablereptxt3				= "announce when someone set up a Repair Bot"
rsctablereptxt4				= "announce when someone is casting a Soul Well"
rsctableused1				= "has set up a Feast!"
rsctableused2				= "has set up a Cauldron with Flasks!"
rsctableused3				= "has set up a Repair Bot!"
rsctableused4				= "is casting a Soul Well!"
rscfoodstillthere			= "Feast of Food is still there"
rsclocpoths17				= "Nobody used Healthstone (Tonic)"
rsclocpoths172				= "Everyone has used Healthstone (Tonic)"
rsclocpoths18				= "Used healthstones (Tonic)"
rsclocpoths182				= "NOT used healthstones (Tonic)"
rscwhousehstext				= "Used healthstone (Tonic)"
rscwhousehstext2			= "NOT used healthstone (Tonic)"
rscprepots            = "Prepots"
rscadditionalstat1    = "Stam"
rscadditionalstat2    = "Int"
rscadditionalstat3    = "Spirit"
rscadditionalstat4    = "Agi"
rscadditionalstat5    = "Str"
rscadditionalstatbonus = "bonus"
rscpartanonsfoodadd        = "count %s food"
rsceating				= "E"
rsceating2				= "E"
rsccheckrunes			= "Check runes"
rscflasktext69				= "No Runes"


end
